pub(crate) fn flat_projected_columns(
metadata: &RegionMetadata,
format_projection: &FormatProjection,
json_target_types: &Arc<BTreeMap<ColumnId, JsonNativeType>>,
) -> Vec<(ColumnId, ConcreteDataType)>Expand description
Returns ids and datatypes of columns after applying the projection and JSON2 target types.
It adds the time index column if it doesn’t present in the projection.